;; Generated package description from muse.el
(define-package "muse" "3.20.1" "Authoring and publishing tool for Emacs" 'nil :url "http://mwolson.org/projects/EmacsMuse.html" :keywords '("hypermedia"))
